@@ -14,24 +14,29 @@
 # define    EKEYREJECTED    129
 #endif
 
-extern int (*action)(int *argc, char *argv[]);
-extern int batchmode;
-extern size_t bpslimit;
 extern char *bwlimit;
-extern int dryrun;
-extern int g_archive;
-extern int g_perms;
-extern int hex;
 extern char *iface;
-extern unsigned int ifx;
 extern char *keyfile;
-extern int loopback;
 extern char *password;
 extern char *progname;
-extern unsigned char secretkey[crypto_pwhash_STRBYTES];
+extern int (*action)(int *argc, char *argv[]);
+extern int archive;
+extern int batchmode;
+extern int dryrun;
+extern int hex;
+extern int loopback;
 extern int quiet;
+extern int recurse;
+extern int remote;
+extern int setgroup;
+extern int setowner;
+extern int setperms;
+extern int settimes;
 extern int verbose;
 extern int version;
+extern size_t bpslimit;
+extern unsigned char secretkey[crypto_pwhash_STRBYTES];
+extern unsigned int ifx;
 
 /* default action is to do nothing, successfully */
 int succeed(int *argc, char *argv[]);
